plottool_ibeis
==============

|Pypi| |Downloads| |Codecov| |GithubActions| 


Helpers for matplotlib computer vision plots for the IBEIS / WildMe project

Repos relevant to the ibeis project:

* https://github.com/Erotemic/plottool_ibeis

* https://github.com/Erotemic/guitool_ibeis

* https://github.com/Erotemic/dtool_ibeis

* https://github.com/Erotemic/vtool_ibeis

* https://github.com/Erotemic/pyflann_ibeis

* https://github.com/Erotemic/pyhesaff

* https://github.com/Erotemic/utool

* https://github.com/Erotemic/ibeis


This project is maintained for the benefit of IBEIS, but is not recommended for
use in other projects.


For new developement the (generally useful) tools in this repo are largely
superceded by Kitware projects:

* https://gitlab.kitware.com/computer-vision/kwimage

* https://gitlab.kitware.com/computer-vision/kwplot


.. |CircleCI| image:: https://circleci.com/gh/Erotemic/plottool_ibeis.svg?style=svg
    :target: https://circleci.com/gh/Erotemic/plottool_ibeis
.. |Travis| image:: https://img.shields.io/travis/Erotemic/plottool_ibeis/master.svg?label=Travis%20CI
   :target: https://travis-ci.org/Erotemic/plottool_ibeis?branch=master
.. |Appveyor| image:: https://ci.appveyor.com/api/projects/status/github/Erotemic/plottool_ibeis?branch=master&svg=True
   :target: https://ci.appveyor.com/project/Erotemic/plottool_ibeis/branch/master
.. |Codecov| image:: https://codecov.io/github/Erotemic/plottool_ibeis/badge.svg?branch=master&service=github
   :target: https://codecov.io/github/Erotemic/plottool_ibeis?branch=master
.. |Pypi| image:: https://img.shields.io/pypi/v/plottool_ibeis.svg
   :target: https://pypi.python.org/pypi/plottool_ibeis
.. |Downloads| image:: https://img.shields.io/pypi/dm/plottool_ibeis.svg
   :target: https://pypistats.org/packages/plottool_ibeis
.. |ReadTheDocs| image:: https://readthedocs.org/projects/plottool_ibeis/badge/?version=latest
    :target: http://plottool_ibeis.readthedocs.io/en/latest/
.. |GithubActions| image:: https://github.com/Erotemic/plottool_ibeis/actions/workflows/tests.yml/badge.svg?branch=main
    :target: https://github.com/Erotemic/plottool_ibeis/actions?query=branch%3Amain
   
